@@ -32,12 +32,10 @@
 #include <MailTransport/TransportManager>
 
 #include <KConfigGroup>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotification>
 #include <KSharedConfig>
-#include <KToolInvocation>
 #include <KWindowSystem>
 
 #include <QComboBox>
@@ -123,8 +121,6 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
         changer->setShowDialogsOnError(false);
     }
 
-    KIconLoader::global()->addAppDir(QStringLiteral("korgac"));
-
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup generalConfig(config, "General");
 
@@ -144,7 +140,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     int suspendVal = defSuspendVal;
     int suspendUnit = defSuspendUnit;
 
-    QWidget *topBox = new QWidget(this);
+    auto topBox = new QWidget(this);
     setWindowTitle(i18nc("@title:window", "Reminders"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("korgac")));
     auto buttonBox = new QDialogButtonBox(this);
@@ -206,13 +202,13 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     mIncidenceTree = new QTreeWidget(topBox);
     mIncidenceTree->setColumnCount(3);
     mIncidenceTree->setSortingEnabled(true);
-    const QStringList headerLabels = (QStringList(i18nc("@title:column reminder title", "Title"))
+    const QStringList headerLabels = (QStringList(i18nc("@title:column reminder summary", "Summary"))
                                       << i18nc("@title:column happens at date/time", "Date Time") << i18nc("@title:column trigger date/time", "Trigger Time"));
     mIncidenceTree->setHeaderLabels(headerLabels);
 
     QHeaderView *header = mIncidenceTree->header();
     header->setSectionResizeMode(0, QHeaderView::Stretch);
-    mIncidenceTree->headerItem()->setToolTip(0, i18nc("@info:tooltip", "The event or to-do title"));
+    mIncidenceTree->headerItem()->setToolTip(0, i18nc("@info:tooltip", "The event or to-do summary"));
 
     header->setSectionResizeMode(1, QHeaderView::ResizeToContents);
     mIncidenceTree->headerItem()->setToolTip(1, i18nc("@info:tooltip", "The reminder is set for this date/time"));
@@ -241,7 +237,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     mDetailView->hide();
     mLastItem = nullptr;
 
-    QWidget *suspendBox = new QWidget(topBox);
+    auto suspendBox = new QWidget(topBox);
     auto suspendBoxHBoxLayout = new QHBoxLayout(suspendBox);
     suspendBoxHBoxLayout->setContentsMargins({});
     topLayout->addWidget(suspendBox);
@@ -285,10 +281,10 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
 
     QDBusConnection dbusConn = QDBusConnection::sessionBus();
     if (dbusConn.interface()->isServiceRegistered(QString::fromLatin1(s_fdo_notifications_service))) {
-        OrgFreedesktopDBusPropertiesInterface *propsIface = new OrgFreedesktopDBusPropertiesInterface(QString::fromLatin1(s_fdo_notifications_service),
-                                                                                                      QString::fromLatin1(s_fdo_notifications_path),
-                                                                                                      dbusConn,
-                                                                                                      this);
+        auto propsIface = new OrgFreedesktopDBusPropertiesInterface(QString::fromLatin1(s_fdo_notifications_service),
+                                                                    QString::fromLatin1(s_fdo_notifications_path),
+                                                                    dbusConn,
+                                                                    this);
         connect(propsIface, &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged, this, &AlarmDialog::slotDBusNotificationsPropertiesChanged);
     }
 }
@@ -900,7 +896,7 @@ void AlarmDialog::showDetails(QTreeWidgetItem *item)
         return;
     }
 
-    auto *reminderItem = dynamic_cast<ReminderTreeItem *>(item);
+    auto reminderItem = dynamic_cast<ReminderTreeItem *>(item);
 
     if (!reminderItem) {
         mDetailView->setIncidence(Akonadi::Item());
@@ -1000,7 +996,7 @@ void AlarmDialog::keyPressEvent(QKeyEvent *e)
 bool AlarmDialog::openIncidenceEditorThroughKOrganizer(const Incidence::Ptr &incidence)
 {
     if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.korganizer"))) {
-        if (KToolInvocation::startServiceByDesktopName(QStringLiteral("org.kde.korganizer"), QString())) {
+        if (!QDBusConnection::sessionBus().interface()->startService(QStringLiteral("org.kde.korganizer")).isValid()) {
             KMessageBox::error(this, i18nc("@info", "Could not start KOrganizer so editing is not possible."));
             return false;
         }
