@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef SUMMARYWIDGET_H
-#define SUMMARYWIDGET_H
+#pragma once
 
 #include <Akonadi/Calendar/ETMCalendar>
 #include <KontactInterface/Summary>
@@ -38,7 +37,6 @@ public:
         return 3;
     }
 
-    Q_REQUIRED_RESULT QStringList configModules() const override;
     void configUpdated();
     void updateSummary(bool force = false) override
     {
@@ -68,4 +66,3 @@ private:
     bool mShowMineOnly = false;
 };
 
-#endif
