@@ -155,7 +155,7 @@ void TodoSummaryWidget::updateView()
 
         QString str;
 
-        for (const KCalendarCore::Todo::Ptr &todo : qAsConst(prList)) {
+        for (const KCalendarCore::Todo::Ptr &todo : std::as_const(prList)) {
             bool makeBold = false;
             int daysTo = -1;
 
@@ -278,7 +278,7 @@ void TodoSummaryWidget::updateView()
         mLabels.append(noTodos);
     }
 
-    for (QLabel *label : qAsConst(mLabels)) {
+    for (QLabel *label : std::as_const(mLabels)) {
         label->show();
     }
 }
@@ -361,11 +361,6 @@ bool TodoSummaryWidget::eventFilter(QObject *obj, QEvent *e)
     return KontactInterface::Summary::eventFilter(obj, e);
 }
 
-QStringList TodoSummaryWidget::configModules() const
-{
-    return QStringList() << QStringLiteral("kcmtodosummary.desktop");
-}
-
 bool TodoSummaryWidget::startsToday(const KCalendarCore::Todo::Ptr &todo)
 {
     return todo->hasStartDate() && todo->dtStart().date() == QDate::currentDate();
