@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KOPREFSDIALOGPLUGINS_H
-#define KOPREFSDIALOGPLUGINS_H
+#pragma once
 
 #include "kprefsdialog.h"
 #include <QSet>
@@ -23,7 +22,7 @@ class KOPrefsDialogPlugins : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
-    explicit KOPrefsDialogPlugins(QWidget *parent);
+    explicit KOPrefsDialogPlugins(QWidget *parent, const QVariantList &args = {});
     ~KOPrefsDialogPlugins() override;
 
 protected Q_SLOTS:
@@ -48,4 +47,3 @@ private:
     QSet<QString> mDecorationsAtAgendaViewBottom;
 };
 
-#endif // KOPREFSDIALOGPLUGINS_H
