@@ -14,6 +14,7 @@
 #include "koprefs.h"
 #include "widgets/kitemiconcheckcombo.h"
 #include <KLocalizedString>
+#include <KPluginFactory>
 #include <QCheckBox>
 #include <QFrame>
 #include <QGroupBox>
@@ -22,15 +23,10 @@
 #include <QTabWidget>
 #include <QVBoxLayout>
 
-extern "C" {
-Q_DECL_EXPORT KCModule *create_korganizerconfigviews(QWidget *parent, const char *)
-{
-    return new KOPrefsDialogViews(parent);
-}
-}
+K_PLUGIN_CLASS_WITH_JSON(KOPrefsDialogViews, "korganizer_configviews.json")
 
-KOPrefsDialogViews::KOPrefsDialogViews(QWidget *parent)
-    : Korganizer::KPrefsModule(KOPrefs::instance(), parent)
+KOPrefsDialogViews::KOPrefsDialogViews(QWidget *parent, const QVariantList &args)
+    : Korganizer::KPrefsModule(KOPrefs::instance(), parent, args)
     , mMonthIconComboBox(new KItemIconCheckCombo(KItemIconCheckCombo::MonthType, this))
     , mAgendaIconComboBox(new KItemIconCheckCombo(KItemIconCheckCombo::AgendaType, this))
 {
@@ -42,14 +38,14 @@ KOPrefsDialogViews::KOPrefsDialogViews(QWidget *parent)
     connect(mAgendaIconComboBox, &KPIM::KCheckComboBox::checkedItemsChanged, this, &Korganizer::KPrefsModule::slotWidChanged);
 
     // Tab: Views->General
-    QFrame *generalFrame = new QFrame(this);
+    auto generalFrame = new QFrame(this);
     tabWidget->addTab(generalFrame, QIcon::fromTheme(QStringLiteral("view-choose")), i18nc("@title:tab general settings", "General"));
 
     QBoxLayout *generalLayout = new QVBoxLayout(generalFrame);
 
     // GroupBox: Views->General->Display Options
     auto gdisplayLayout = new QVBoxLayout;
-    QGroupBox *gdisplayBox = new QGroupBox(i18nc("@title:group", "Display Options"));
+    auto gdisplayBox = new QGroupBox(i18nc("@title:group", "Display Options"));
 
     QBoxLayout *nextDaysLayout = new QHBoxLayout;
     gdisplayLayout->addLayout(nextDaysLayout);
@@ -68,7 +64,7 @@ KOPrefsDialogViews::KOPrefsDialogViews(QWidget *parent)
 
     // GroupBox: Views->General->Date Navigator
     auto datenavLayout = new QVBoxLayout;
-    QGroupBox *datenavBox = new QGroupBox(i18nc("@title:group", "Date Navigator"));
+    auto datenavBox = new QGroupBox(i18nc("@title:group", "Date Navigator"));
     datenavLayout->addWidget(addWidBool(KOPrefs::instance()->dailyRecurItem())->checkBox());
     datenavLayout->addWidget(addWidBool(KOPrefs::instance()->weeklyRecurItem())->checkBox());
     datenavLayout->addWidget(addWidBool(KOPrefs::instance()->highlightTodosItem())->checkBox());
@@ -79,14 +75,14 @@ KOPrefsDialogViews::KOPrefsDialogViews(QWidget *parent)
     generalLayout->addStretch(1);
 
     // Tab: Views->Agenda View
-    QFrame *agendaFrame = new QFrame(this);
+    auto agendaFrame = new QFrame(this);
     tabWidget->addTab(agendaFrame, QIcon::fromTheme(QStringLiteral("view-calendar-workweek")), i18nc("@title:tab", "Agenda View"));
 
     QBoxLayout *agendaLayout = new QVBoxLayout(agendaFrame);
 
     // GroupBox: Views->Agenda View->Display Options
     auto adisplayLayout = new QVBoxLayout;
-    QGroupBox *adisplayBox = new QGroupBox(i18nc("@title:group", "Display Options"));
+    auto adisplayBox = new QGroupBox(i18nc("@title:group", "Display Options"));
 
     auto hourSizeLayout = new QHBoxLayout;
     adisplayLayout->addLayout(hourSizeLayout);
@@ -124,14 +120,14 @@ KOPrefsDialogViews::KOPrefsDialogViews(QWidget *parent)
     agendaLayout->addStretch(1);
 
     // Tab: Views->Month View
-    QFrame *monthFrame = new QFrame(this);
+    auto monthFrame = new QFrame(this);
     tabWidget->addTab(monthFrame, QIcon::fromTheme(QStringLiteral("view-calendar-month")), i18nc("@title:tab", "Month View"));
 
     QBoxLayout *monthLayout = new QVBoxLayout(monthFrame);
 
     // GroupBox: Views->Month View->Display Options
     auto mdisplayLayout = new QVBoxLayout;
-    QGroupBox *mdisplayBox = new QGroupBox(i18nc("@title:group", "Display Options"));
+    auto mdisplayBox = new QGroupBox(i18nc("@title:group", "Display Options"));
     /*mdisplayLayout->addWidget(
           addWidBool( KOPrefs::instance()->enableMonthScrollItem() )->checkBox() );*/
     mdisplayLayout->addWidget(addWidBool(KOPrefs::instance()->showTimeInMonthViewItem())->checkBox());
@@ -152,21 +148,21 @@ KOPrefsDialogViews::KOPrefsDialogViews(QWidget *parent)
     monthLayout->addStretch(1);
 
     // Tab: Views->Todo View
-    QFrame *todoFrame = new QFrame(this);
+    auto todoFrame = new QFrame(this);
     tabWidget->addTab(todoFrame, QIcon::fromTheme(QStringLiteral("view-calendar-tasks")), i18nc("@title:tab", "Todo View"));
 
     QBoxLayout *todoLayout = new QVBoxLayout(todoFrame);
 
     // GroupBox: Views->Todo View->Display Options
     auto tdisplayLayout = new QVBoxLayout;
-    QGroupBox *tdisplayBox = new QGroupBox(i18nc("@title:group", "Display Options"));
+    auto tdisplayBox = new QGroupBox(i18nc("@title:group", "Display Options"));
     tdisplayLayout->addWidget(addWidBool(KOPrefs::instance()->sortCompletedTodosSeparatelyItem())->checkBox());
     tdisplayBox->setLayout(tdisplayLayout);
     todoLayout->addWidget(tdisplayBox);
 
     // GroupBox: Views->Todo View->Other
     auto otherLayout = new QVBoxLayout;
-    QGroupBox *otherBox = new QGroupBox(i18nc("@title:group", "Other Options"));
+    auto otherBox = new QGroupBox(i18nc("@title:group", "Other Options"));
     otherLayout->addWidget(addWidBool(KOPrefs::instance()->recordTodosInJournalsItem())->checkBox());
     otherBox->setLayout(otherLayout);
     todoLayout->addWidget(otherBox);
@@ -180,3 +176,5 @@ void KOPrefsDialogViews::usrReadConfig()
     KOPrefs::instance()->eventViewsPreferences()->setAgendaViewIcons(mAgendaIconComboBox->checkedIcons());
     KOPrefs::instance()->eventViewsPreferences()->setMonthViewIcons(mMonthIconComboBox->checkedIcons());
 }
+
+#include "koprefsdialogviews.moc"
