@@ -8,8 +8,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_VIEWS_KOLISTVIEW_H
-#define KORG_VIEWS_KOLISTVIEW_H
+#pragma once
 
 #include "koeventview.h"
 
@@ -72,4 +71,3 @@ private:
     EventViews::ListView *mListView = nullptr;
 };
 
-#endif
